@@ -1,6 +1,6 @@
 use 5.10.1;
 
-our $VERSION = '0.1001'; # VERSION
+our $VERSION = '0.1002'; # VERSION
 # ABSTRACT: Insert PODNAME for Moops classes.
 
 package Dist::Zilla::Plugin::PodnameFromClassname;
@@ -43,7 +43,7 @@ Dist::Zilla::Plugin::PodnameFromClassname - Insert PODNAME for Moops classes.
 
 =head1 VERSION
 
-Version 0.1001, released 2015-01-15.
+Version 0.1002, released 2015-01-15.
 
 =head1 SYNOPSIS
 
@@ -65,9 +65,9 @@ Results in:
 
 =head1 DESCRIPTION
 
-Dist::Zilla::Plugin::PodnameFromClassname is useful together with L<Moops> and L<Pod::Weaver>. Since Moops classes generally don't have a C<package> statement C<Pod::Weaver> can't pick up the module name.
+Dist::Zilla::Plugin::PodnameFromClassname is useful together with L<Moops> and L<Pod::Weaver>. Since Moops classes generally don't also have a C<package> statement C<Pod::Weaver> can't pick up the module name.
 
-Using this plugin, and adding a C<#PODCLASSNAME> directive fixes that by replacing that directive with C<#PODNAME: $classname>.
+Using this plugin and adding a C<# PODCLASSNAME> directive fixes that. It replaces that directive with C<# PODNAME: $classname>.
 
 There are a few simple rules:
 
@@ -75,15 +75,15 @@ There are a few simple rules:
 
 =item *
 
-There must be at least one line (of anything) before the C<#PODCLASSNAME> directive.
+There must be at least one line (of anything) before the C<# PODCLASSNAME> directive.
 
 =item *
 
-There must be at least one line (of anything) between the C<#PODCLASSNAME> directive and the C<class> statement.
+There must be at least one line (of anything) between the C<# PODCLASSNAME> directive and the C<class> statement.
 
 =item *
 
-The C<#PODCLASSNAME> directive must be before the C<class> statement.
+The C<# PODCLASSNAME> directive must be before the C<class> statement.
 
 =back
 
